@@ -1,4 +1,4 @@
-UCRCD = function( series1,
+UCRCD = function(series1,
                      series2,
                      display = T,
                      alpha = 0.05,
@@ -14,12 +14,12 @@ UCRCD = function( series1,
 {
   c2i <- length(series1) - length(series2)
   c2 = c2i + 1
-  
+
   tot <- c(series1, series2)
   data1 <- cumsum(series1)
   data2 <- cumsum(series2)
   end <- length(series1)
-  
+
   if (c2i > 0) {
     step <- c2i
     s1 <- series1[1:step]
@@ -28,19 +28,19 @@ UCRCD = function( series1,
     s2 <- c(rep(0, step))
     Z1 <- cumsum(s1)
     Z2 <- cumsum(s2)
-    
+
     BMs1 <- BM(s1, display = F)
     model1 <- BMs1$model
     m1 <- BMs1$Estimate[1, 1]
     p1a <- BMs1$Estimate[2, 1]
     q1a <- BMs1$Estimate[3, 1]
-    
+
     m1_ <- BMs1$Estimate[1, ]
     p1a_ <- BMs1$Estimate[2, ]
     q1a_ <- BMs1$Estimate[3, ]
-    
+
     pred_BM1 <- make.instantaneous(fitted(BMs1))
-    
+
     o_bass <- matrix()
     o_bass <- cbind(t, s1, s2, Z1, Z2)
     p_bass <- matrix()
@@ -50,10 +50,10 @@ UCRCD = function( series1,
     colnames(o_bass) <- c("t", "s1", "s2", "Z1", "Z2")
     colnames(p_bass) <- c("t", "pred_1", "pred_2")
   }
-  
-  
+
+
   #######################################################
-  
+
   if (par == "unique") {
     parms <- list(
       mc = (m1 + m2) * 2,
@@ -63,9 +63,9 @@ UCRCD = function( series1,
       q2 = q2,
       delta = delta
     )
-    
+
     t <- seq(c2, end, by = 1)
-    
+
     Z1 <- cumsum(series1)
     Z2 <- cumsum(series2)
     data <- matrix()
@@ -78,7 +78,7 @@ UCRCD = function( series1,
       variable.name = "product",
       value.name = "response"
     )
-    
+
     model <- function(t, parms) {
       Z = Z1 + Z2
       mc = parms$mc
@@ -90,10 +90,10 @@ UCRCD = function( series1,
       z1 = mc * (p1c + (q1c + delta) * Z1 / mc + q1c * Z2 / mc) * (1 - Z /
                                                                      mc)
       z2 = mc * (p2 + (q2 - delta) * Z1 / mc + q2 * Z2 / mc) * (1 - Z /
-                                                                     mc)
+                                                                  mc)
       return(list(z1 = z1, z2 = z2, t = t))
     }
-    
+
     res.model <- function(parms) {
       estimates = model(t = t, parms)
       data <- data.frame(t = estimates$t,
@@ -108,11 +108,11 @@ UCRCD = function( series1,
       residual <- preddf$response - expdf$response
       return (residual)
     }
-    
+
     fitval1 = nls.lm(
       par = parms,
       fn = res.model,
-      control = nls.lm.control(maxiter = 1000, maxfev = 10000)
+      control = nls.lm.control(maxiter = 1024, maxfev = 10000)
     )
     summary <- summary(fitval1)
     sssss <- signif(summary$coefficients, digits = 3)
@@ -124,7 +124,7 @@ UCRCD = function( series1,
     aa[, 5] <- sssss[, 4]
     names(aa) <- c("Estimate", "Std.Error", "Lower", "Upper",
                    "p-value")
-    
+
     parest = as.list(coef(fitval1))
     mc = parest$mc
     p1c = parest$p1c
@@ -132,7 +132,7 @@ UCRCD = function( series1,
     p2 = parest$p2
     q2 = parest$q2
     delta = parest$delta
-    
+
     if (c2i > 0) {
       Estimate <- c(m1, p1a, q1a, mc, p1c, q1c + delta, q1c, p2, q2, q2 - delta)
       names(Estimate) <-
@@ -146,7 +146,7 @@ UCRCD = function( series1,
           "p2",
           "q2",
           "q2-delta")
-      
+
       Estimate1 <- rbind(m1_, p1a_, q1a_, aa)
       rownames(Estimate1) <- c("ma",
                                "p1a",
@@ -162,8 +162,8 @@ UCRCD = function( series1,
         data.frame(t = estimates$t,
                    pred_1 = estimates$z1,
                    pred_2 = estimates$z2)
-      
-      
+
+
       data$t <- c(c2:end)
       data_o <- matrix()
       data_o <- rbind(o_bass, data)
@@ -173,16 +173,13 @@ UCRCD = function( series1,
       data_p <- rbind(p_bass, z_prime)
       z_prime <- data_p
     }
-    
+
     if (c2i == 0) {
       Estimate <- c(mc, p1c, q1c + delta, q1c, p2, q2, q2 - delta)
       names(Estimate) <- c("mc", "p1c", "q1c+delta", "q1c", "p2",
                            "q2", "q2-delta")
       Estimate1 <- aa
-      rownames(Estimate1) <- c("ma",
-                               "p1a",
-                               "q1a",
-                               "mc",
+      rownames(Estimate1) <- c("mc",
                                "p1c",
                                "p2",
                                "q1c",
@@ -193,11 +190,11 @@ UCRCD = function( series1,
         data.frame(t = estimates$t,
                    pred_1 = estimates$z1,
                    pred_2 = estimates$z2)
-      
+
       data$t <- c(c2:end)
       z_prime$t <- c(c2:end)
     }
-    
+
     obs = melt(
       data[, c(1:3)],
       id.var = c("t"),
@@ -212,9 +209,9 @@ UCRCD = function( series1,
     )
     res = obs$consumption - pred$consumption
   }
-  
+
   ##################################################################################
-  
+
   if (par == "double") {
     parms <- list(
       mc = (m1 + m2) * 2,
@@ -225,9 +222,9 @@ UCRCD = function( series1,
       delta = delta,
       gamma = gamma
     )
-    
+
     t <- seq(c2, end, by = 1)
-    
+
     Z1 <- cumsum(series1)
     Z2 <- cumsum(series2)
     data <- matrix()
@@ -240,7 +237,7 @@ UCRCD = function( series1,
       variable.name = "product",
       value.name = "response"
     )
-    
+
     model <- function(t, parms) {
       Z = Z1 + Z2
       mc = parms$mc
@@ -253,10 +250,10 @@ UCRCD = function( series1,
       z1 = mc * (p1c + (q1c + delta) * Z1 / mc + q1c * Z2 / mc) * (1 - Z /
                                                                      mc)
       z2 = mc * (p2 + (q2 - gamma) * Z1 / mc + q2 * Z2 / mc) * (1 - Z /
-                                                                     mc)
+                                                                  mc)
       return(list(z1 = z1, z2 = z2, t = t))
     }
-    
+
     res.model <- function(parms) {
       estimates = model(t = t, parms)
       data <- data.frame(t = estimates$t,
@@ -271,11 +268,11 @@ UCRCD = function( series1,
       residual <- preddf$response - expdf$response
       return (residual)
     }
-    
+
     fitval1 = nls.lm(
       par = parms,
       fn = res.model,
-      control = nls.lm.control(maxiter = 1000, maxfev = 10000)
+      control = nls.lm.control(maxiter = 1024, maxfev = 10000)
     )
     summary <- summary(fitval1)
     sssss <- signif(summary$coefficients, digits = 3)
@@ -287,7 +284,7 @@ UCRCD = function( series1,
     aa[, 5] <- sssss[, 4]
     names(aa) <- c("Estimate", "Std.Error", "Lower", "Upper",
                    "p-value")
-    
+
     parest = as.list(coef(fitval1))
     mc = parest$mc
     p1c = parest$p1c
@@ -296,7 +293,7 @@ UCRCD = function( series1,
     q2 = parest$q2
     delta = parest$delta
     gamma = parest$gamma
-    
+
     if (c2i > 0) {
       Estimate <- c(m1, p1a, q1a, mc, p1c, q1c + delta, q1c, p2, q2, q2 - gamma)
       names(Estimate) <-
@@ -326,7 +323,7 @@ UCRCD = function( series1,
         data.frame(t = estimates$t,
                    pred_1 = estimates$z1,
                    pred_2 = estimates$z2)
-      
+
       data$t <- c(c2:end)
       data_o <- matrix()
       data_o <- rbind(o_bass, data)
@@ -336,16 +333,13 @@ UCRCD = function( series1,
       data_p <- rbind(p_bass, z_prime)
       z_prime <- data_p
     }
-    
+
     if (c2i == 0) {
       Estimate <- c(mc, p1c, q1c + delta, q1c, p2, q2, q2 - gamma)
       names(Estimate) <- c("mc", "p1c", "q1c+delta", "q1c", "p2",
                            "q2", "q2-gamma")
       Estimate1 <- aa
-      rownames(Estimate1) <- c("ma",
-                               "p1a",
-                               "q1a",
-                               "mc",
+      rownames(Estimate1) <- c("mc",
                                "p1c",
                                "p2",
                                "q1c",
@@ -357,11 +351,11 @@ UCRCD = function( series1,
         data.frame(t = estimates$t,
                    pred_1 = estimates$z1,
                    pred_2 = estimates$z2)
-      
+
       data$t <- c(c2:end)
       z_prime$t <- c(c2:end)
     }
-    
+
     obs = melt(
       data[, c(1:3)],
       id.var = c("t"),
@@ -376,9 +370,9 @@ UCRCD = function( series1,
     )
     res = obs$consumption - pred$consumption
   }
-  
+
   ################################################
-  
+
   if (c2i > 0) {
     data <-
       list(obs$consumption[1:end], obs$consumption[(end + c2):(2 * end)])
@@ -388,7 +382,7 @@ UCRCD = function( series1,
                    obs$consumption[(end + c2):(2 * end)] - pred$consumption[(end +
                                                                                c2):(2 * end)])
   }
-  
+
   if (c2i == 0) {
     data <-
       list(obs$consumption[1:end], obs$consumption[(end + c2):(2 * end)])
@@ -397,41 +391,58 @@ UCRCD = function( series1,
     residu <- list(obs$consumption[1:end] - pred$consumption[1:end],
                    obs$consumption[(end + c2):(2 * end)] - pred$consumption[(end +
                                                                                c2):(2 * end)])
-    
+
   }
-  
+
   tss <- sum((obs$consumption - mean(obs$consumption)) ^ 2)
   rss <- sum((obs$consumption - pred$consumption) ^ 2)
   r.squared <- 1 - rss / tss
-  
+
   ss1 <- obs$consumption[1:end]
   ss2 <- obs$consumption[(end + c2):(2 * end)]
   cc1 <- cumsum(ss1)
   cc2 <- cumsum(ss2)
-  
+
   pp1 <- pred$consumption[1:end]
   pp2 <- pred$consumption[(end + c2):(2 * end)]
   gg1 <- cumsum(pp1)
   gg2 <- cumsum(pp2)
-  
+
+  FITTED <- list(gg1, gg2)
+  DATA <- list(cc1, cc2)
+  RESIDUALS <- list(gg1 - cc1, gg2 - cc2)
+
   t <- c(1:end)
   t2 <- c(c2:end)
-  
-  
+
+
   if (display == T) {
     par(mfrow = c(1, 2))
+    M <- max(cc1, cc2, gg1, gg2)
+    MM <- M * 1.30
     plot(
       t,
-      cumsum(ss1),
+      cc1,
       main = "Cumulative",
-      
-      ylim = c(0, sum(ss1) + sum(ss1) * 50 / 100),
+
+      ylim = c(0, MM),
       ylab = "z(t)",
       type = 'b',
       pch = 19,
       cex = 0.8
     )
-    
+
+    lines(t2, gg2, col = "#5C2E91", lwd = 2)
+    lines(t, gg1, col = 2, lwd = 2)
+    lines(
+      t2,
+      cc2,
+      pch = 19,
+      type = "b",
+      col = 3,
+      cex = 0.8
+    )
+
     legend(
       "topright",
       legend = c("Observed 1", "Observed 2",
@@ -442,18 +453,7 @@ UCRCD = function( series1,
       col = c(1, 3, 2, "#5C2E91"),
       cex = 0.8
     )
-    
-    lines(t2, cumsum(pp2), col = "#5C2E91", lwd = 2)
-    lines(t, cumsum(pp1), col = 2, lwd = 2)
-    lines(
-      t2,
-      cumsum(ss2),
-      pch = 19,
-      type = "b",
-      col = 3,
-      cex = 0.8
-    )
-    
+
     M <- max(ss1, ss2, pp1, pp2)
     MM <- M * 1.30
     plot(
@@ -476,7 +476,7 @@ UCRCD = function( series1,
       col = 3 ,
       cex = 0.8
     )
-    
+
     legend(
       "topright",
       legend = c("Observed 1", "Observed 2",
@@ -487,16 +487,12 @@ UCRCD = function( series1,
       col = c(1, 3, 2, "#5C2E91"),
       cex = 0.8
     )
-    
+
     par(mfrow = c(1, 1))
-    
+
   }
-  
-  FITTED <- list(cumsum(pp1), cumsum(pp2))
-  DATA <- list(cumsum(ss1), cumsum(ss2))
-  RESIDUALS <- list(cumsum(pp1) - cumsum(ss1), cumsum(pp2) - cumsum(ss2))
-    
-    cl <- match.call()
+
+  cl <- match.call()
   ao <- list(
     model = model,
     type = "UCRCD Model",
@@ -512,7 +508,7 @@ UCRCD = function( series1,
     data.i = data,
     call = cl
   )
-  
+
   class(ao) <- "Dimora"
   invisible(ao)
 }
